@@ -17,6 +17,7 @@ from typing import Iterable
 from typing import Iterator
 from typing import List
 from typing import Optional
+from typing import Sequence
 from typing import TypeVar
 from typing import Union
 from typing import cast
@@ -58,6 +59,71 @@ else:
         """Adds MutableMapping mixin while pretending to be a builtin dict"""
 
 
+ItemT = TypeVar("ItemT", bound="Item")
+
+
+@overload
+def item(value: bool) -> "Bool":
+    ...
+
+
+@overload
+def item(value: int) -> "Integer":
+    ...
+
+
+@overload
+def item(value: float) -> "Float":
+    ...
+
+
+@overload
+def item(value: str) -> "String":
+    ...
+
+
+@overload
+def item(value: datetime) -> "DateTime":
+    ...
+
+
+@overload
+def item(value: date) -> "Date":
+    ...
+
+
+@overload
+def item(value: time) -> "Time":
+    ...
+
+
+@overload
+def item(value: Sequence[dict]) -> "AoT":
+    ...
+
+
+@overload
+def item(value: Sequence) -> "Array":
+    ...
+
+
+@overload
+def item(value: dict, _parent: "Array" = ..., _sort_keys: bool = ...) -> "InlineTable":
+    ...
+
+
+@overload
+def item(
+    value: dict, _parent: Optional["Item"] = ..., _sort_keys: bool = ...
+) -> "Table":
+    ...
+
+
+@overload
+def item(value: ItemT) -> ItemT:
+    ...
+
+
 def item(
     value: Any, _parent: Optional["Item"] = None, _sort_keys: bool = False
 ) -> "Item":
@@ -426,6 +492,10 @@ class Item:
         """The TOML representation"""
         raise NotImplementedError()
 
+    def unwrap(self):
+        """Returns as pure python object (ppo)"""
+        raise NotImplementedError()
+
     # Helpers
 
     def comment(self, comment: str) -> "Item":
@@ -544,6 +614,9 @@ class Integer(int, Item):
         if re.match(r"^[+\-]\d+$", raw):
             self._sign = True
 
+    def unwrap(self) -> int:
+        return int(self)
+
     @property
     def discriminant(self) -> int:
         return 2
@@ -612,6 +685,9 @@ class Float(float, Item):
         if re.match(r"^[+\-].+$", raw):
             self._sign = True
 
+    def unwrap(self) -> float:
+        return float(self)
+
     @property
     def discriminant(self) -> int:
         return 3
@@ -673,6 +749,9 @@ class Bool(Item):
 
         self._value = bool(t)
 
+    def unwrap(self) -> bool:
+        return bool(self)
+
     @property
     def discriminant(self) -> int:
         return 4
@@ -721,8 +800,7 @@ class DateTime(Item, datetime):
         second: int,
         microsecond: int,
         tzinfo: Optional[tzinfo],
-        trivia: Trivia,
-        raw: str,
+        *_: Any,
         **kwargs: Any,
     ) -> datetime:
         return datetime.__new__(
@@ -748,12 +826,28 @@ class DateTime(Item, datetime):
         second: int,
         microsecond: int,
         tzinfo: Optional[tzinfo],
-        trivia: Trivia,
-        raw: str,
+        trivia: Optional[Trivia] = None,
+        raw: Optional[str] = None,
+        **kwargs: Any,
     ) -> None:
-        super().__init__(trivia)
+        super().__init__(trivia or Trivia())
 
-        self._raw = raw
+        self._raw = raw or self.isoformat()
+
+    def unwrap(self) -> datetime:
+        (
+            year,
+            month,
+            day,
+            hour,
+            minute,
+            second,
+            microsecond,
+            tzinfo,
+            _,
+            _,
+        ) = self._getstate()
+        return datetime(year, month, day, hour, minute, second, microsecond, tzinfo)
 
     @property
     def discriminant(self) -> int:
@@ -803,7 +897,16 @@ class DateTime(Item, datetime):
 
         return result
 
-    def _new(self, result):
+    def replace(self, *args: Any, **kwargs: Any) -> datetime:
+        return self._new(super().replace(*args, **kwargs))
+
+    def astimezone(self, tz: tzinfo) -> datetime:
+        result = super().astimezone(tz)
+        if PY38:
+            return result
+        return self._new(result)
+
+    def _new(self, result) -> "DateTime":
         raw = result.isoformat()
 
         return DateTime(
@@ -849,6 +952,10 @@ class Date(Item, date):
 
         self._raw = raw
 
+    def unwrap(self) -> date:
+        (year, month, day, _, _) = self._getstate()
+        return date(year, month, day)
+
     @property
     def discriminant(self) -> int:
         return 6
@@ -879,6 +986,9 @@ class Date(Item, date):
 
         return result
 
+    def replace(self, *args: Any, **kwargs: Any) -> date:
+        return self._new(super().replace(*args, **kwargs))
+
     def _new(self, result):
         raw = result.isoformat()
 
@@ -918,6 +1028,10 @@ class Time(Item, time):
 
         self._raw = raw
 
+    def unwrap(self) -> datetime:
+        (hour, minute, second, microsecond, tzinfo, _, _) = self._getstate()
+        return time(hour, minute, second, microsecond, tzinfo)
+
     @property
     def discriminant(self) -> int:
         return 7
@@ -929,6 +1043,22 @@ class Time(Item, time):
     def as_string(self) -> str:
         return self._raw
 
+    def replace(self, *args: Any, **kwargs: Any) -> time:
+        return self._new(super().replace(*args, **kwargs))
+
+    def _new(self, result):
+        raw = result.isoformat()
+
+        return Time(
+            result.hour,
+            result.minute,
+            result.second,
+            result.microsecond,
+            result.tzinfo,
+            self._trivia,
+            raw,
+        )
+
     def _getstate(self, protocol: int = 3) -> tuple:
         return (
             self.hour,
@@ -957,6 +1087,15 @@ class Array(Item, _CustomList):
         self._multiline = multiline
         self._reindex()
 
+    def unwrap(self) -> str:
+        unwrapped = []
+        for v in self:
+            if isinstance(v, Item):
+                unwrapped.append(v.unwrap())
+            else:
+                unwrapped.append(v)
+        return unwrapped
+
     @property
     def discriminant(self) -> int:
         return 8
@@ -988,12 +1127,16 @@ class Array(Item, _CustomList):
         if not self._multiline or not self._value:
             return "[{}]".format("".join(v.as_string() for v in self._value))
 
-        s = "[\n" + self.trivia.indent + " " * 4
-        s += (",\n" + self.trivia.indent + " " * 4).join(
-            v.as_string() for v in self._value if not isinstance(v, Whitespace)
+        s = "[\n"
+        s += "".join(
+            self.trivia.indent
+            + " " * 4
+            + v.as_string()
+            + ("\n" if isinstance(v, Comment) else ",\n")
+            for v in self._value
+            if not isinstance(v, Whitespace)
         )
-        s += ",\n"
-        s += "]"
+        s += self.trivia.indent + "]"
 
         return s
 
@@ -1197,6 +1340,17 @@ class AbstractTable(Item, _CustomDict):
             if k is not None:
                 dict.__setitem__(self, k.key, v)
 
+    def unwrap(self):
+        unwrapped = {}
+        for k, v in self.items():
+            if isinstance(k, Key):
+                k = k.key
+            if isinstance(v, Item):
+                v = v.unwrap()
+            unwrapped[k] = v
+
+        return unwrapped
+
     @property
     def value(self) -> "container.Container":
         return self._value
@@ -1519,6 +1673,9 @@ class String(str, Item):
         self._t = t
         self._original = original
 
+    def unwrap(self) -> str:
+        return self.as_string()
+
     @property
     def discriminant(self) -> int:
         return 11
@@ -1577,6 +1734,15 @@ class AoT(Item, _CustomList):
         for table in body:
             self.append(table)
 
+    def unwrap(self) -> str:
+        unwrapped = []
+        for t in self._body:
+            if isinstance(t, Item):
+                unwrapped.append(t.unwrap())
+            else:
+                unwrapped.append(t)
+        return unwrapped
+
     @property
     def body(self) -> List[Table]:
         return self._body
@@ -1668,6 +1834,9 @@ class Null(Item):
     def __init__(self) -> None:
         pass
 
+    def unwrap(self) -> str:
+        return None
+
     @property
     def discriminant(self) -> int:
         return -1
